@@ -17,7 +17,7 @@ eBay::API::Simple::Shopping
 
 =head1 SYNPOSIS
 
-  my $call = ebay::API::Simple::Shopping->new();
+  my $call = eBay::API::Simple::Shopping->new();
   $call->execute( 'FindItemsAdvanced', { QueryKeywords => 'shoe' } );
 
   if ( $call->has_error() ) {
@@ -88,6 +88,8 @@ sub new {
     $self->api_config->{response_encoding} ||= 'XML'; # JSON, NV, SOAP
     $self->api_config->{request_encoding}  ||= 'XML';
 
+    $self->_load_credentials();
+    
     return $self;    
 }
 
@@ -240,7 +242,7 @@ sub _fish_ebay_ini {
         '/etc/ebay.ini',
     );
     
-    foreach my $file ( @files ) {        
+    foreach my $file ( reverse @files ) {        
         if ( open( FILE, "<", $file ) ) {
         
             while ( my $line = <FILE> ) {
